; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also  cov diag eigsm svdcmp setmaskp setmaskt plot setgopt
; ----------------------------------------------------------------------------
;   Macro        SMScancarm2
; ----------------------------------------------------------------------------
;   Description  SMScancarm2 performs a canonical correlation analysis 
;                for the car marks data ("carmean2.dat") and shows 
;                a plot of the first canonical variables.
; ----------------------------------------------------------------------------
  library("xplore")
  library("graphic")
  library("plot")
;
  x=read("carmean2")
  x=x[,2:9]
  x=x[,4|3|(1:2)|(5:8)]         ; reorder: price value econ serv 
                                ;          design sport safe easy
;
  xrows="audi"|"bmw"|"citroen"|"ferrari"
  xrows=xrows|"fiat"|"ford"|"hyundai"|"jaguar"
  xrows=xrows|"lada"|"mazda"|"mercedes"|"mitsubishi"
  xrows=xrows|"nissan"|"opel_corsa"|"opel_vectra"
  xrows=xrows|"peugeot"|"renault"|"rover"|"toyota"
  xrows=xrows|"trabant"|"vw_golf"|"vw_passat"|"wartburg"
;
  s=cov(x)                      ; covariance
  s
;
  sa=s[1:2,1:2]                 ; covariance of price & value
  sb=s[3:8,3:8]                 ; covariance of rest
  sa
  sb
;
  {ea,va}=eigsm(sa)             ; spectral decomposition 
  {eb,vb}=eigsm(sb)             ; spectral decomposition 
  sa2=va*diag(1./sqrt(ea))*va'  ; sa^(-1/2)
  sb2=vb*diag(1./sqrt(eb))*vb'  ; sb^(-1/2)
;
  k=sa2*s[1:2,3:8]*sb2          ; matrix k
  {d,l,g}=svd(k')              ; singular value decomposition
  l
;
  a=sa2*g                       ; canonical vectors a
  b=sb2*d                       ; canonical vectors b
  a
  b
  eta=x[,1:2]*a[,1]             ; canonical variable eta 
  phi=x[,3:8]*b[,1]             ; canonical variable phi 
  eta
  phi
  etaphi=eta~phi 
;  
  setmaskt(etaphi,xrows,0,0,18) ; add text labels
  setmaskp(etaphi,0,0,0)        ; no points
  plot(etaphi)
  setgopt(plotdisplay,1,1,"title","car marks data","xlabel","eta2","ylabel","phi2","border",0)

