; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also  cov diag eigsm svdcmp setmaskp setmaskt plot setgopt
; ----------------------------------------------------------------------------
;   Macro        SMScanfood
; ----------------------------------------------------------------------------
;   Description  SMScanfood performs a canonical correlation analysis 
;                for french food data and plots the first canonical variables.
; ----------------------------------------------------------------------------
  library("xplore")
  library("graphic")
  library("plot")
;
  x=read("food")
  x=x[,2:8]
;
  xrows="MA2"|"EM2"|"CA2"|"MA3"
  xrows=xrows|"EM3"|"CA3"|"MA4"|"EM4"
  xrows=xrows|"CA4"|"MA5"|"EM5"|"CA5"
;
  s=cov(x)                      ; covariance
  s
;
  sa=s[1:5,1:5]                     ; covariance of price
  sb=s[6:7,6:7]                 ; covariance of rest
;
  {ea,va}=eigsm(sa)             ; spectral decomposition 
  {eb,vb}=eigsm(sb)             ; spectral decomposition 
  sa2=va*diag(1./sqrt(ea))*va'  ; sa^(-1/2)
  sb2=vb*diag(1./sqrt(eb))*vb'  ; sb^(-1/2)
;
  k=sa2*s[1:5,6:7]*sb2          ; matrix k
  {g,l,d}=svd(k)               ; singular value decomposition
  l
;
  a=sa2*g                       ; canonical vectors a
  b=sb2*d                       ; canonical vectors b
  eta=x[,1:5]*a[,1]             ; canonical variable eta 
  phi=x[,6:7]*b[,1]             ; canonical variable phi 
  etaphi=eta~phi 
;  
  setmaskt(etaphi,xrows,0,0,15) ; add text labels
  setmaskp(etaphi,0,0,0)        ; no points
  plot(etaphi)
  setgopt(plotdisplay,1,1,"title","french food data","xlabel","eta1","ylabel","phi1")

