; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also  cov diag eigsm svdcmp setmaskp setmaskt plot setgopt
; ----------------------------------------------------------------------------
;   Macro        SMScantime
; ----------------------------------------------------------------------------
;   Description  SMScantime performs a canonical correlation analysis 
;                for timebudget data and plots the first canonical variables.
; ----------------------------------------------------------------------------
  library("xplore")
  library("graphic")
  library("plot")
;
  x=read("timebudget")
  x=x[,1:7|9:10]
  x=(x-mean(x))./sqrt(var(x))
;
  xrows="maus"|"waus"|"wnus"|"mmus"
  xrows=xrows|"wmus"|"msus"|"wsus"|"mawe"
  xrows=xrows|"wawe"|"wnwe"|"mmwe"|"wmwe"
  xrows=xrows|"mswe"|"wswe"|"mayo"|"wayo"
  xrows=xrows|"wnyo"|"mmyo"|"wmyo"|"msyo"
  xrows=xrows|"wsyo"|"maes"|"waea"|"wnea"
  xrows=xrows|"mmea"|"wmea"|"msea"|"wsea"
  ;
  s=cov(x)                      ; covariance
  s
;
  sa=s[1:4,1:4]                     ; covariance of price
  sb=s[5:9,5:9]                 ; covariance of rest
;
  {ea,va}=eigsm(sa)             ; spectral decomposition 
  {eb,vb}=eigsm(sb)             ; spectral decomposition 
  sa2=va*diag(1./sqrt(ea))*va'  ; sa^(-1/2)
  sb2=vb*diag(1./sqrt(eb))*vb'  ; sb^(-1/2)
;
  k=sa2*s[1:4,5:9]*sb2         ; matrix k
  {d,l,g}=svd(k')               ; singular value decomposition
  l
;
  a=sa2*g                       ; canonical vectors a
  b=sb2*d                       ; canonical vectors b
  eta=x[,1:4]*a[,3]             ; canonical variable eta 
  phi=x[,5:9]*b[,3]             ; canonical variable phi 
  etaphi=eta~phi 
;  
  setmaskt(etaphi,xrows,0,0,15) ; add text labels
  setmaskp(etaphi,0,0,0)        ; no points
  plot(etaphi)
  setgopt(plotdisplay,1,1,"title","time budget data","xlabel","eta1","ylabel","phi1")


s=2
n=rows(x)
p=cols(sa2)
q=cols(sb2)
bartlett=-(n-(p+q+3)/2)*log(prod(1-(l[(s+1):rows(l)])^2))
bartlett
qfc(0.95,(p-s)*(q-s))

