; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also      agglom tree distance
; ----------------------------------------------------------------------------
;   Macro        SMSclusbank3
; ----------------------------------------------------------------------------
;   Description  SMSclusbank3 performs cluster analysis for  20 
;                randomly chosen banknotes from 
;                the swiss banknotes dataset 
; ----------------------------------------------------------------------------
library("xplore")
proc()=main()
 setsize(800, 400)
 dd=createdisplay(1,2)
 x=read("bank2")                 ; reads data
 randomize(2006)                 ; sets random seed
 n=20                            ; sample size
; xi=1:10  
 xi=ceil(200*uniform(n))         ; indices of chosen subsample
; xi=37|32|3|98|67|50|89|171|116|168|148|194|108|135|193|145|165|114|146|173
 xx=index(x, xi)                 ; extracts subsample from x
 xxi=string("%3.0f", xi)         ; labels
 ;
 x=xx-mean(xx)
 {e, v}=eigsm(cov(x))            ; eigensystem analysis
 tmp=sort(e~v',-1)               ; sort by eigenvalues
 e=tmp[,1]
 v=tmp[,2:7]
 y=x*(v')                        ; PCA transformation
 y=y[,1:2]
 tc=(xi<101)
 labels=string("%.0f", xi)
 setmaskt(y, labels, tc, 0, 14)
 setmaskp(y, 0, 0, 0)
 show(dd, 1, 1, y)
 setgopt(dd, 1, 1, "xlabel", "first PC", "ylabel", "second PC")
 setgopt(dd, 1, 1, "title", "20 Swiss bank notes")
 setgopt(dd, 1, 1, "xoffset", 10|10, "yoffset", 10|10, "border", 0)
 ;print(dd, "fig114.ps")
 ;error()
 ;
 ; second part
 d=distance(xx, "l1")        ; L1 distance
 t=agglom(d, "WARD", 5)       ; here. cluster anal., Ward algor.
 g=tree(t.g, 0, "CENTER")
 g=g.points
 l = 5.*(1:rows(g)/5) + (0:4)' - 4 
 setmaskl (g, l, 0, 1, 1) 
 setmaskp (g, 0, 0, 0) 
 ; show the dendrogram 
 numbers=(0:(rows(xx)-1))
 numbers=numbers~((-1)*matrix(rows(xx)))
 setmaskp(numbers, 0, 0, 0)
 tg=paf(t.g[,2], t.g[,2]!=0)
 labels=string("%.0f", xi[tg])
 setmaskt(numbers, labels, 0, 0, 10)  
; ddd=createdisplay(1, 1)
 show(dd, 1, 2, g, numbers) 
 setgopt(dd, 1, 2, "xlabel","Ward algorithm" , "ylabel","L1 distance" )
 setgopt(dd, 1, 2, "title", "Dendrogram for 20 Swiss bank notes ", "xoffset", 10|10, "yoffset", 10|10)  
 setgopt(dd, 1, 2, "xmajor", 50, "xorigin", -10, "border", 0)
endp                                 
main()