; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also  paf sum svdcmp cumsum sqrt setmaskp setmaskt createdisplay grxline setgopt
; ----------------------------------------------------------------------------
;   Macro        SMScorrhealth
; ----------------------------------------------------------------------------
;   Description  SMScorrhealth performs a correspondence analysis for the US health 
;                ("ushealth.dat"), shows the eigenvalues of the singular value
;                decomposition of the chi-matrix,projections on the first 3 axes
;		 and absolute contributions. It also displays graphical the
;                factorial decomposition, the regions are selected in 4 groups
;		 (Northeast(blue), Midwest(green), South(cyan) and West(red)). 
; ----------------------------------------------------------------------------
  library("graphic")           ; load graphic library
  library("xplore")            ; load xplore library
;
  x=read("ushealth.dat")
  x
  col = x[,cols(x)-1]					 ; region numbers (blue-Northeast, green-Midwest, cyan-South, red- West)
  col
  x=x[,4:10]
  xrows= "ME"|"NH"|"VT"|"MA"|"RI"|"CT"|"NY"|"NJ"|"PA"|"OH"|"IN"|"IL"|"MI"
  xrows = xrows|"WI"|"MN"|"IA"|"MO"|"ND"|"SD"|"NE"|"KS"|"DE"|"MD"
  xrows = xrows|"VA"|"WV"|"NC"|"SC"|"GA"|"FL"|"KY"|"TN"|"AL"|"MS"|"AR"|"LA"|"OK"
  xrows = xrows|"TX"|"MT"|"ID"|"WY"|"CO"|"NM"|"AZ"|"UT"|"NV"|"WA"|"OR"|"CA"|"AK"|"HI"          
                               ; labels for regions
  xcols="acc"|"card"|"canc"|"pul"|"pneu"|"diab"|"liv"
                               ; labels for crimes
;
  wak = 0                      ; set to 0/1 to ex/include Alaska!!
;
  wak = matrix(rows(x)-2)|wak|1
  x = paf(x,wak)  
  xrows = paf(xrows,wak)
  col = paf(col,wak)   
  a=sum(x,2)                   ; row sums
  b=sum(x)'                    ; column sums
  e=a*b'/sum(a)
;
  C=(x-e)./sqrt(e)             ; chi-matrix
  {g,l,d}=svd(C)               ; singular value decomposition
  sort((l^2)~(l^2)./sum(l^2)~cumsum(l^2)./sum(l^2))  ; eigenvalues & percentages
;
  r=(l'.*g)./sqrt(a)
  s=(l'.*d)./sqrt(b)
;
  p = rows(l)
  car=sum(x,2).*(r^2)/(l^2)'   ; contribution in r
  cas=sum(x)'.*(s^2)/(l^2)'    ; contribution in s
  c1 = car[,1:3]
  c2 = cas[,1:3]
  
  out1 = #(1:rows(r))~r[,1:3]~c1											 ; projections of the rows(regions) on the first 3 axes 
 ; out1 = sort(out1,5)
  out2 = #(1:rows(s))~s[,1:3]~c2											 ; projections of the columns(crimes) on the first 3 axes 
 ; out2 = sort(out2,5)
  out1 
  out2
  
;
  
;
  r=r[,1:2]
  s=s[,1:2]
  
;

;  setmaskt(r,xrows,col,0,15)
  setmaskt(r,xrows,0,3,12)
  setmaskp(r,0,col+1,8)
  setmaskt(s,xcols,4,0,28)
  setmaskp(s,0,0,0)
;
  di=createdisplay(1,1)        ; create display
  xline=grxline(0,(1.2*r[,2])|(0.8*r[,2])|(1.2*s[,2])|(0.8*s[,2]))
  yline=gryline(0,(1.2*r[,1])|(0.8*r[,1])|(1.2*s[,1])|(0.8*s[,1]))
  show(di,1,1,r,s,xline,yline)
                                 ; display with 0-axes
  setgopt(di,1,1,"title","US health data","xlabel","r_1,s_1","ylabel","r_2,s_2","border",0)


