; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also      mean cov inv sum denest setmaskp setmaskl createdisplay show setgopt
; ----------------------------------------------------------------------------
;   Macro        SMSdisfbank
; ----------------------------------------------------------------------------
;   Description  SMSdisfbank perform a fisher discrimination analysis 
;                of 20 Swiss bank notes ("bank2.dat") and computes the
;                miss-classification rates for the whole dataset 
; ----------------------------------------------------------------------------
  library("xplore")
  x=read("bank2")         ; reads the bank data
  randomize(2006)                 ; sets random seed
  n=20                            ; sample size
  xi=ceil(200*uniform(n))         ; indices of chosen subsample
 
  xx=index(x, xi)                 ; extracts subsample from x
;
  xxg=x[1:100,]
  xxf=x[101:200,]
;
  xg=paf(xx,xi<101)           ; genuine bank notes
  xf=paf(xx,xi>100)           ; forged bank notes
; 
  ng=rows(xg)
  nf=rows(xf)
;
  mg=mean(xg)             ; mean of genuine notes
  mf=mean(xf)             ; mean of forged notes
  m=(mf+mg)/2             ; mean of all notes
;
  w=((ng-1)*cov(xg)+(nf-1)*cov(xf))  ; matrix w for within-sum-of-squares
  d=mg-mf                 ; vector d
  a=inv(w)*d'             ; inverse of w times d
;
;
  yg=(xxg-m)*a             ; projection of 180 genuine notes
  yf=(xxf-m)*a             ; projection of 180 forged notes
;
  xgtest=(xxg-m)*a
  sum(xgtest.<0)          ; counts number of misclassified
                          ; genuine notes 
  xftest=(xxf-m)*a 
  sum(xftest.>0)          ; counts number of misclassified  
                         ; genuine notes  
