; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also      mean cov denest setmaskp setmaskl createdisplay show setgopt
; ----------------------------------------------------------------------------
;   Macro        SMSdisfbank2
; ----------------------------------------------------------------------------
;   Description  SMSdisfbank2 calculates fisher discrimination rule and 
;                first PC of all Swiss bank notes ("bank2.dat")
; ----------------------------------------------------------------------------
  library("xplore")
  library ("plot")
  library ("smoother")
  x=read("bank2")         ; reads the bank data
  ;x = (x-mean(x))/sqrt(var(x))
  x = transform(x, grc.prep.sphere)
  h = 2.62.*rows(x)^(-1/5)
  xg=x[1:100,]
  xf=x[101:200,]
; 
  ng=rows(xg)
  nf=rows(xf)
;
  mg=mean(xg)             ; mean of genuine notes
  mf=mean(xf)             ; mean of forged notes
  m=(mf+mg)/2             ; mean of all notes
;
  w=((ng-1)*cov(xg)+(nf-1)*cov(xf))  ; matrix w for within-sum-of-squares
  d=mg-mf                 ; vector d
  a=inv(w)*d'             ; inverse of w times d
;
;
setenv("outputformat","% 8.4f")
"Fisher's LDA projection"
a
;
;
;
{e,v}=eigsm(cov(x))                  ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[1,2:7]'
"First PC"
v
;
xa=x*a
xa=(xa-mean(xa))/sqrt(var(xa))
xv=x*v
xv=(xv-mean(xv))/sqrt(var(xv))
xgr  = grid(-3, 0.1, 61)
id = (3*matrix(100))|(4*matrix(100))
xap   = grdot(xa)
d    = createdisplay (1,1)
setmaskp(xap, 4, id, 5)
xap[,2] = -0.01-0.08.*xap[,2]
fa   = setmask(denxest(xa, h, "rqua", xgr), "line", "red", "dashed")
xvp  = grdot(xv)
setmaskp(xvp, 1, id, 5)
xvp[,2] = -0.11-0.08.*xvp[,2]
fv   = setmask(denxest(xv, h, "rqua", xgr), "line", "blue", "solid")
show (d, 1, 1, xap, fa, xvp, fv)
setgopt(d,1,1,"title","Fisher's LDA and PC projection","border",0,"xlabel"," ","ylabel","densities of projections")
