; ---------------------------------------------------------------------
; EBook       sms
; ---------------------------------------------------------------------
; See_also    ppftind
; ---------------------------------------------------------------------
; Macro       SMSeppbank
; ---------------------------------------------------------------------
; Description We read the Swiss banknote data and sphere them to run 
;             EPP on them. We select n randomly choosen one 
;             dimensional projections in the six dimensional space of
;             the data. For each set of projected data the 
;             Friedman-Tukex-Index is applied to judge the 
;             "interestingness" of the projection.
;
;             In the graphics we see the density for the standard
;             normal distributed data (green) and the estimated
;             densities for the best (red) and the worst (blue)
;             projections found. Additionally we see a dotplot
;             of the projections. Below we see the estimated value
;             of the Friedman-Tukey index for each computed projection 
;             (green = standard normal, red = best, blue = worst).
; ---------------------------------------------------------------------
; Author      Sigbert Klinke, 011102
;             Z. Hlavka, 060712
; ---------------------------------------------------------------------
proc(mini)=ppexample(x, h, n)
  xg   = grid(-4, 0.1, 81)
  id = (3*matrix(100))|(4*matrix(100))
  zd   = setmask(xg~pdfn(xg), "line", "green", "dotted")
; select a starting vector
  p    = normal(cols(x))
  p    = p/sqrt(sum(p^2))
; compute index for starting vector
  xp   = x*p
  imin = ppftind(xp, h)
  imax = imin  
  xi   = grdot(xp)
  setmaskp(xi, 1, id, 5)
  xi[,2] = -0.11-0.08*xi[,2]
  fi   = setmask(denxest(xp, h, "rqua", xg), "line", "blue")
  xa   = grdot(xp)
  setmaskp(xa, 4, id, 5)
  xa[,2] = -0.01-0.08*xa[,2]
  fa   = setmask(denxest(xp, h, "rqua", xg), "line", "red" , "dashed")
; create display 
  d    = createdisplay (1,1)
;  setfractions(d,2|1,1)
  show (d, 1, 1, xa, fa, xi, fi)
  inds = 1/sqrt(4*pi)|imax
  pind = (1:rows(inds))~inds
;  cind = 2|1
;  setmaskp (pind, cind)
;  show (d, 2, 1, pind)
; search for better projection vector
  i    = 0
  pmin = 1
  pmax = 1
  while (i<n)
    i   = i+1
    tit = string("%.0f directions",i)
    p   = normal(cols(x))
    p   = p/sqrt(sum(p^2))
    xp  = x*p
    ind = ppftind(xp, h)
;    xi   = setmask(grdot(xp))
;    xi[,2] = -0.1.*xi[,2]
;    fi   = setmask(denxest(xp, h, "rqua", xg), "line")
;    show (d, 1, 1, xs, fs, xf, ff, xi, fi)
    inds = inds|ind
    pind = (1:rows(inds))~inds
;    cind = 0.*matrix(rows(pind))
;    cind[maxind(inds)] = 4
;    cind[minind(inds)] = 1
;    cind[1] = 2
;    setmaskp(pind, cind)
;    show (d, 2, 1, pind)
    if (ind>imax)
      imax = ind
      xa   = grdot(xp)
      setmaskp(xa, 4, id, 5)
      ;xa   = setmask(grdot(xp), "red")
      xa[,2] = -0.01-0.08.*xa[,2]
      fa   = setmask(denxest(xp, h, "rqua", xg), "line", "red", "dashed")
      show (d, 1, 1, xa, fa, xi, fi)
      setgopt(d,1,1,"title",tit,"border",0)
      pmin = i
    endif      
    if (ind<imin)
      imin = ind
      xi   = grdot(xp)
      setmaskp(xi, 1, id, 5)
     ;xi   = setmask(grdot(xp), "blue")
      xi[,2] = -0.11-0.08*xi[,2]
      fi   = setmask(denxest(xp, h, "rqua", xg), "line", "blue")
      show (d, 1, 1, xa, fa, xi, fi)
      setgopt(d,1,1,"title",tit,"border",0)
      pmax = i
      mini = p
    endif
  endo
  setgopt(d,1,1,"title",tit,"border",0,"xlabel"," ","ylabel","densities of chosen projections")
endp
library ("plot")
library ("smoother")
library ("pp")
; read the banknote data 
x = read ("bank2")
; select the fourth and sixth column and
; sphere the data
x = transform(x, grc.prep.sphere)
; standardize the data
;x = (x-mean(x))/sqrt(var(x))
randomize(0)
; choose bandwidth related to Scott's rule
h = 2.62.*rows(x)^(-1/5)
; choose number of projections
n = 10000
inde=ppexample(x, h, n)
"Friedman-Tukey projection"
inde