; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also      read factoranalysis varimax cov eigsm
; ----------------------------------------------------------------------------
;   Macro        SMSfactbank
; ----------------------------------------------------------------------------
;   Description  SMSfact demontstrates the principal factors method and 
;                performs factor analysis of the bank notes data set
;
; ----------------------------------------------------------------------------
library("xplore")
library("stats")
library("plot")
;
x=read("bank2")                      ; reads the data file
y=x[,1:6]                            
setenv("outputformat","%8.4f")
r=corr(x)
"correlation matrix"
r
h=max(abs(r-diag(matrix(6))))
psi=1-h
"specific variances"
psi
"reduced cor. matrix"
rcm=r-diag(psi')
rcm
; spectral decomposition of rcm
{e,v}=eigsm(rcm)                  ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:7]'
;
"eigenvalues and proportions of explained variance"
(e~(e/sum(e))~(cumsum(e)/sum(e)))'
"all eigenvectors"
v
"k=2 factor loadings"
q=v[,1:2]*diag(sqrt(e[1:2]))
q
b=factoranalysis(y,2,"PFM",10)
"iterate the PFM 10 times"
"  Q1       Q2        comm.    spec.   "
b.loadings~b.communalities~b.specifics
;varim=varimax(b.loadings)
;varim

labels="X1"|"X2"|"X4"|"X3"|"X5"|"X6"
q=setmask(q,"text",labels)
;
ucircle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
ucircle=setmask(ucircle,"line","thin","dashed")
xline=setmask(#(-1.1,1.1)~#(0,0),"line")
yline=setmask(#(0,0)~#(-1.1,1.1),"line")

theta=3.14*(5/12)
rot=(cos(theta)~sin(theta))|(-sin(theta)~cos(theta))

qr=q*rot
qr=setmask(qr,"text",labels)

setsize(600,300)
dic=createdisplay(1,2)
show(dic,1,1,q,ucircle,xline,yline)
setgopt(dic,1,1,"title","Swiss bank notes","xlabel","q1","ylabel","q2","border",0)
show(dic,1,2,qr,ucircle,xline,yline)
setgopt(dic,1,2,"title","Swiss bank notes","xlabel","q1","ylabel","q2","border",0)
 
