; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also      read factoranalysis varimax cov eigsm
; ----------------------------------------------------------------------------
;   Macro        SMSfactfood
; ----------------------------------------------------------------------------
;   Description  SMSfactfood demontstrates the maximum likelihood method 
;                and varimax rotation and 
;                performs factor analysis of the french food data set
;
; ----------------------------------------------------------------------------
library("xplore")
library("stats")
library("plot")
;
name="French food"
;
x=readm("food")                      ; reads the data file
t=x.text
;t="bread"|"vegetables"|"fruits"|"meat"|"poultry"|"milk"|"wine"
y=(x.double-mean(x.double))/sqrt(var(x.double))
y=y'                        
setenv("outputformat","%8.4f")
b=factoranalysis(y,3,"PFM",10)
"  PFM"
"  Q1       Q2        comm.    spec.   "
b.loadings~b.communalities~b.specifics
varim=varimax(b.loadings)
"  PFM (varimax)"
"  Q1       Q2        comm.    spec.   "
varim~b.communalities~b.specifics
labels=t
;
q123=setmask(varim,"text",labels)
q12=setmask(varim[,1|2],"text",labels)
q23=setmask(varim[,2|3],"text",labels)
q13=setmask(varim[,1|3],"text",labels)
;
theta1=0
theta2=0.5
theta3=1.5
rot3=(cos(theta3)~sin(theta3)~0)|(-sin(theta3)~cos(theta3)~0)|(0~0~1)
rot2=(cos(theta2)~0~sin(theta2))|(0~1~0)|(-sin(theta2)~0~cos(theta2))
rot1=(1~0~0)|(0~cos(theta1)~sin(theta1))|(0~(-sin(theta1))~cos(theta1))
qr=b.loadings*rot1*rot2*rot3
qr123=setmask(qr,"text",labels)
qr12=setmask(qr[,1|2],"text",labels)
qr23=setmask(qr[,2|3],"text",labels)
qr13=setmask(qr[,1|3],"text",labels)
"  PFM (rotation by theta)"
"  Q1       Q2        comm.    spec.   "
qr~b.communalities~b.specifics
;
ucircle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
ucircle=setmask(ucircle,"line","thin","dashed")
xline=setmask(#(-1.1,1.1)~#(0,0),"line")
yline=setmask(#(0,0)~#(-1.1,1.1),"line")
;setsize(600,300)
;dic=createdisplay(1,2)
;show(dic,1,1,q,ucircle,xline,yline)
;setgopt(dic,1,1,"title","French food","xlabel","q1","ylabel","q2","border",0)
;show(dic,1,2,qr,ucircle,xline,yline)
;setgopt(dic,1,2,"title","French food (varimax)","xlabel","q1","ylabel","q2","border",0)
diq=createdisplay(2,2)
show(diq,1,1,q12,ucircle,xline,yline)
show(diq,2,2,q23,ucircle,xline,yline)
show(diq,2,1,q13,ucircle,xline,yline)
;show(diq,1,2,q123)
namev=name+" (varimax)"
setgopt(diq,1,1,"title",namev,"xlabel","q1","ylabel","q2","border",0)
setgopt(diq,2,2,"title",namev,"xlabel","q2","ylabel","q3","border",0)
setgopt(diq,2,1,"title",namev,"xlabel","q1","ylabel","q3","border",0)
setgopt(diq,1,2,"border",0)
diqr=createdisplay(2,2)
show(diqr,1,1,qr12,ucircle,xline,yline)
show(diqr,2,2,qr23,ucircle,xline,yline)
show(diqr,2,1,qr13,ucircle,xline,yline)
setgopt(diqr,1,1,"title",name,"xlabel","q1","ylabel","q2","border",0)
setgopt(diqr,2,2,"title",name,"xlabel","q2","ylabel","q3","border",0)
setgopt(diqr,2,1,"title",name,"xlabel","q1","ylabel","q3","border",0)
setgopt(diqr,1,2,"border",0)
