; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also     gls grbox maxind setmaskl setmaskp show setgopt
; ----------------------------------------------------------------------------
;   Macro       SMSlinregpull
; ----------------------------------------------------------------------------
;   Description  SMSlinregpull computes a linear regression of sales (X1) on 
;                price (X2) from the pullovers data set ("pullover.dat")-black line, a 
;								 boxplot of the standard errors and then recalculate the linear 
;								 regression without observation which errors are outliers(blue line).
; ----------------------------------------------------------------------------
 library("xplore")
 library("stats")
 library("graphic")
;
 setsize(800,400)
 z=read("pullover")              ; reads the pullovers data
 y=z[,1]                         ; prices (X2)
 x=matrix(rows(z))~z[,2]         ; constant & sales (X1)
;
 beta=gls(x, y)                  ; computes beta (lin. regression)
 eps = y - x * beta							 ; computes standard errors
 e = 1:(rows(eps))~eps
 i1 = minind(eps)
 i2 = maxind(eps)
 out = (x[i1,2]~y[i1,])|(x[i2,2]~y[i2,])       ; the outliers
 setmaskp(out, 4, 4, 8)										 ; are red points	
 
 line=min(x[,2])|max(x[,2])
 m = line~(((1|1)~line)*beta)      				 ; regression line with all observations, 
 setmaskl(m, (1: rows(m))', 0, 5, 2)			 ; black line	
 setmaskp(m, 0, 0, 0)
 i = #(i1,i2)
 i = sort(i)
 ynew = z[(i[1]+1):(i[2]-1),1]|z[(i[2]+1):(rows(z)),1]								 ; new data, without error-outliers
 xnew = z[(i[1]+1):(i[2]-1),2]|z[(i[2]+1):(rows(z)),2]
 xnew = matrix(rows(xnew))~xnew
 betanew = gls(xnew,ynew)									 ; new linear regression
 dnew=xnew[,2]~ynew                        ; new data points
 line=min(xnew[,2])|max(xnew[,2])
 mnew = line~(((1|1)~line)*betanew)      	 ; new regression line
 setmaskl(mnew, (1: rows(mnew))', 1, 1, 2) ; is blue
 setmaskp(mnew, 0, 0, 0)
 b1d=grbox(eps,4)                      ; boxplot of the standard errors
 bd1=grrot(b1d,1)                      ; rotation of the plot 
 di=createdisplay(1, 2)
 show(di, 1, 1, mnew,dnew,out,m)       ; shows data, both regression lines and outliers
 axesoff()
 show(di, 1, 2, bd1)            			 ; shows the boxplot
 axeson()
 setgopt(di, 1, 1, "title", "regression with outliers")
 setgopt(di, 1, 1, "xlabel","price","ylabel","sales","border",0)
 setgopt(di, 1, 2, "title", "boxplot of residuals","xlim",-0.5|1.5,"border",0)
