; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also  distance eigsm corr setmaskp setmaskt createdisplay show setgopt
; ----------------------------------------------------------------------------
;   Macro        SMSmdsbank
; ----------------------------------------------------------------------------
;   Description  SMSmdsbank performs a multidimensional scaling (MDS)
;                for the bank notes data ("bank2.dat") and shows 
;                a plot of the MDS and the MDS/variables correlations.
; ----------------------------------------------------------------------------
  library("xplore")
;
  x=read("bank2")
 
;
  xvars="length"|"height left"|"height right"|"inner frame low"|"inner frame up"
  xvars=xvars|"diagonal"       ; define variable names
;
  d=distance(x)^2               ; squared distance matrix
;
  B=-0.5*(d-mean(d)-mean(d,2)+mean(mean(d,2)))
                                ; B=HXX'H
  {e,v}=eigsm(B)                ; spectral decomposition
  tmp=sort(e~v',-1)             ; sort by eigenvalues
  e=tmp[,1]
  v=tmp[,2:cols(tmp)]'
;
  D=v[,1:2].*sqrt(e[1:2]')
  xcol=matrix(100)|(2*matrix(100))
  setmaskp(D,(xcol-1)*4,xcol+2,8)             
;
  setsize(800,400)
  di=createdisplay(1,2)
  show(di,1,1,D)
  setgopt(di,1,1, "title", "Metric MDS","border",0)
;
  c=corr(D~x)
  c=c[3:rows(c),1:2]
  setmaskt(c,xvars,0,0,24)      ; add text labels
  setmaskp(c,0,0,0)             ; no points
;
  circle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
  setmaskp(circle,0,0,0)
  setmaskl(circle,(0:360)',0,1,2)
;
  show(di,1,2,c,circle)
  setgopt(di,1,2, "title", "Correlations of MDS / Variables","border",0)
  setsize(500,500)

