; ----------------------------------------------------------------------------
; EBook         sms
; ----------------------------------------------------------------------------
;  See_also      isoreg distance eigensm
; ----------------------------------------------------------------------------
;   Macro        SMSnmdscarm
; ----------------------------------------------------------------------------
;   Description  SMSnmdscarm computes the 2D map of 4 cars
;                based on ranks of differences
;                using nonmetric multidimensional scaling
; ----------------------------------------------------------------------------
proc (X)=nonMDS(Dist,text)
 if (rows(Dist)<>rows(text))
  text=string("%2.0f",1:rows(Dist))
 endif
 alpha=0.2
 ; calculate configuration of points in two dimensions
 A=(Dist.^2).*(-0.5)
 n=rows(Dist)
 nn=n^2
 I=diag(matrix(n))
 u=matrix(n)
 H=I-(1/6*(u*u'))
 B=H*A*H
 G=eigensm(B)
 G1=(G.vectors[,1])~(G.vectors[,2])
 G2=diag(G.values[1:2,])
 X=G1*(G2.^0.5)
; X=normal(rows(Dist),2)
 MDS=createdisplay(1,1)
 color=1
 position=3
 pic=X
 setmaskt(pic,text,color,position,24)
 show(MDS,1,1,pic)
 ; iterate Shepard-Kruskal until convergence
 change=1
 STRESS1=1
 iter=0
 n=rows(Dist)
 nn=n^2
 while (((change)>0.0000001)&&(iter<10000))
; while (iter<0)
  iter=iter+1
  ; isotonic regression
  Dist1=vec(distance(X,"euclid"))~floor((0:(nn-1))/n+1)
  Dist1=Dist1~((1:(nn))-(Dist1[,2]-1)*n)
  Dist1=vec(Dist)~Dist1 
  Dist1=sort(Dist1,1)
  Dist2=isoreg(Dist1[,2])
  STRESS0=STRESS1
  STRESS1=(Dist2-Dist1[,1])'*(Dist2-Dist1[,1])/(2*sum(Dist1[,1]^2))
  change=STRESS0-STRESS1
  ; update X
  Xnew=X
  Dist1=Dist1~Dist2
  Dist1=sort(Dist1,4|3)
  D=reshape(Dist1[,2],n|n)+I
  DH=reshape(Dist1[,5],n|n)+I
  shift=alpha*(1-(DH./D))/(n-1)
  i=0
  while (i<n)
   i=i+1 
   Xnew[i,]=X[i,]+sum(shift[,i].*(X.-(X[i,])))
  endo
 X=Xnew 
 if ((iter%1)==0)
  iter~STRESS1
;  MDS=createdisplay(1,1)
;  color=1
;  position=3
  pic=X
  comsc=min(X[,1]|X[,2])|max(X[,1]|X[,2])
  comra=(comsc[2]-comsc[1])/5
  comsc=comsc+(-comra|comra)
  ym=floor(comra*2)
  setmaskp(pic,0,0,0)
  setmaskt(pic,text,color,position,24)
  show(MDS,1,1,pic)
  setgopt(MDS,1,1,"xlim",comsc,"ylim",comsc,"xmajor",ym,"ymajor",ym,"border",0)
 endif
 endo
endp

library("graphic")
library("xplore")
text="Nissan"|"Kia"|"BMW"|"Audi"
Dist=(0|2|4|3)~(2|0|6|5)~(4|6|0|1)~(3|5|1|0) 
X=nonMDS(Dist,text)
;X

