; ----------------------------------------------------------------------------
; EBook          sms
; ----------------------------------------------------------------------------
;  See_also      eigsm order setmaskp setmaskl
; ----------------------------------------------------------------------------
;   Macro        SMSnpcacrime
; ----------------------------------------------------------------------------
;   Description  SMSnpcacrime performs NPCA for the US crime
;                data and shows the first two principal components in 
;                two-dimensional scatterplot. Additionally, a screeplot
;                of the eigenvalues is displayed.
; ----------------------------------------------------------------------------
library("xplore")
library("plot")
;
x=readm("uscrime")                      ; read data
t=x.text
x=x.double
reg=x[,10]
x=x[,3:9]
x=(x-mean(x))./sqrt(var(x))
n=rows(x)
{e,v}=eigsm(cov(x))                  ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:8]'
;
"eigenvalues and proportions of explained variance"
(e~(e/sum(e))~(cumsum(e)/sum(e)))'
"2 eigenvectors"
v[,1:2]'
;
setsize(500,250)
di=createdisplay(1,2)                
show(di,1,2,(1:7)~e)                 ; screeplot of eigenvalues
y=x*v                                ; principal components
;
m=reg  +1                              ; mask for region
x12=y[,1:2]
setmaskp(x12,0,m,8)
setmaskt(x12,string("%1.0f",reg),0,0,8)
;
show(di,1,1,x12)
setgopt(di,1,1,"title","first  vs. second PC","xlabel","pc1","ylabel","pc2","border",0)
setgopt(di,1,2, "title","eigenvalues of S","xlabel","index","ylabel","lambda","border",0)
;
r=corr(y~x)
r=r[8:14,1:2]                ; correlations between variables and pc's
;r=setmask(r,"text","murd"|"rape"|"robb"|"assa"|"burg"|"larc"|"auto")
setmaskp(r,0,0,0)
setmaskt(r,"murd"|"rape"|"robb"|"assa"|"burg"|"larc"|"auto",0,0,20)
;
ucircle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
ucircle=setmask(ucircle,"line","thin","dashed")
xline=setmask(#(-1.1,1.1)~#(0,0),"line")
yline=setmask(#(0,0)~#(-1.1,1.1),"line")
;
setsize(500,500)
dic=createdisplay(1,1)
show(dic,1,1,r,ucircle,xline,yline)
setgopt(dic,1,1,"title","US crime","xlabel","first PC","ylabel","second PC","border",0)
