; ----------------------------------------------------------------------------
; EBook          sms
; ----------------------------------------------------------------------------
;  See_also      eigsm order setmaskp setmaskl
; ----------------------------------------------------------------------------
;   Macro        SMSnpcageopol
; ----------------------------------------------------------------------------
;   Description  SMSpcageopol performs NPCA for the geopol
;                data and shows the first three principal components in 
;                two-dimensional scatterplots. Additionally, a screeplot
;                of the eigenvalues is displayed.
; ----------------------------------------------------------------------------
library("xplore")
library("plot")
;
x=readm("geopol")                      ; read data
t=x.text
x=x.double[,2:10]
x=(x-mean(x))./sqrt(var(x))
n=rows(x)
{e,v}=eigsm(cov(x))                  ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:10]'
;
"eigenvalues and proportions of explained variance"
(e~(e/sum(e))~(cumsum(e)/sum(e)))'
"2 eigenvectors"
v[,1:3]'
;
di=createdisplay(2,2)                
show(di,2,2,(1:9)~e)                 ; screeplot of eigenvalues
y=x*v                                ; principal components
;
x12=y[,1:2]
x23=y[,3|2]
x13=y[,1]~y[,3]
setmaskp(x12,0,0,0)
setmaskp(x23,0,0,0)
setmaskp(x13,0,0,0)
setmaskt(x12,t,0,0,12)
setmaskt(x23,t,0,0,12)
setmaskt(x13,t,0,0,12)
;
show(di,1,1,x12)
show(di,1,2,x23)
show(di,2,1,x13)
setgopt(di,1,1,"title","first  vs. second PC","xlabel","pc1","ylabel","pc2","border",0)
setgopt(di,1,2,"title","third vs. second PC ","xlabel","pc3","ylabel","pc2","border",0)
setgopt(di,2,1,"title","first  vs. third PC ","xlabel","pc1","ylabel","pc3","border",0)
setgopt(di,2,2, "title","eigenvalues of S","xlabel","index","ylabel","lambda","border",0)
;
axeson()
r=corr(y~x)
r12=r[10:18,1:2]                        ; correlations between variables and pc's
r13=r[10:18,1|3]                        ; correlations between variables and pc's
r32=r[10:18,3|2]                        ; correlations between variables and pc's
r123=r[10:18,1:3]
r12=setmask(r12,"text","giph"|"ripo"|"rupo"|"rlpo"|"rspo"|"eltp"|"rnnr"|"nunh"|"nuth")
r13=setmask(r13,"text","giph"|"ripo"|"rupo"|"rlpo"|"rspo"|"eltp"|"rnnr"|"nunh"|"nuth")
r32=setmask(r32,"text","giph"|"ripo"|"rupo"|"rlpo"|"rspo"|"eltp"|"rnnr"|"nunh"|"nuth")
r123=setmask(r123,"text","giph"|"ripo"|"rupo"|"rlpo"|"rspo"|"eltp"|"rnnr"|"nunh"|"nuth")
;
ucircle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
ucircle=setmask(ucircle,"line","thin","dashed")
dum=0*matrix(rows(ucircle.data))
ucircle1=ucircle
ucircle2=ucircle
ucircle3=ucircle
ucircle1.data=ucircle.data~dum
ucircle2.data=dum~ucircle.data
ucircle3.data=ucircle.data[,1]~dum~ucircle.data[,2]
xline=setmask(#(-1.1,1.1)~#(0,0),"line")
yline=setmask(#(0,0)~#(-1.1,1.1),"line")
;
dic=createdisplay(2,2)
show(dic,2,2,(1:rows(e))~e)
setgopt(dic,2,2,"title","Geopol","xlabel","index","ylabel","lambda","border",0)
show(dic,1,1,r12,ucircle,xline,yline)
setgopt(dic,1,1,"title","Geopol","xlabel","first PC","ylabel","second PC","border",0)
show(dic,1,2,r32,ucircle,xline,yline)
setgopt(dic,1,2,"title","Geopol","xlabel","third PC","ylabel","second PC","border",0)
show(dic,2,1,r13,ucircle,xline,yline)
setgopt(dic,2,1,"title","Geopol","xlabel","first PC","ylabel","third PC","border",0)
show(dic,2,2,r123,ucircle1,ucircle2,ucircle3)
