; ----------------------------------------------------------------------------
; EBook          sms
; ----------------------------------------------------------------------------
;  See_also      eigsm order setmaskp setmaskt
; ----------------------------------------------------------------------------
;   Macro        SMSnpcathletic
; ----------------------------------------------------------------------------
;   Description  SMSpcathletic performs NPCA for the athletic records
;                data and shows the first three principal components in 
;                two-dimensional scatterplots. Additionally, a screeplot
;                of the eigenvalues is displayed.
; ----------------------------------------------------------------------------
library("xplore")
library("plot")
;
x=readm("athleleticrecord.dat")                      ; read data
t=x.text
x=x.double
x=(x-mean(x))./sqrt(var(x))
n=rows(x)
{e,v}=eigsm(cov(x))                  ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:9]'
;
"eigenvalues and proportions of explained variance"
(e~(e/sum(e))~(cumsum(e)/sum(e)))'
"2 eigenvectors"
v[,1:2]'
;
di=createdisplay(2,2)                
show(di,2,2,(1:8)~e)                 ; screeplot of eigenvalues
y=x*v                                ; principal components
;
x12=y[,1:2]
x23=y[,2:3]
x13=y[,1]~y[,3]
setmaskp(x12,0,0,0)
setmaskp(x23,0,0,0)
setmaskp(x13,0,0,0)
setmaskt(x12,t,0,0,12)
setmaskt(x23,t,0,0,12)
setmaskt(x13,t,0,0,12)
;
show(di,1,1,x12)
show(di,1,2,x23)
show(di,2,1,x13)
setgopt(di,1,1,"title","first  vs. second PC","xlabel","pc1","ylabel","pc2","border",0)
setgopt(di,1,2,"title","second vs. third PC ","xlabel","pc2","ylabel","pc3","border",0)
setgopt(di,2,1,"title","first  vs. third PC ","xlabel","pc1","ylabel","pc3","border",0)
setgopt(di,2,2, "title","eigenvalues of S","xlabel","index","ylabel","lambda","border",0)
;
r=corr(y~x)
r=r[9:16,1:2]                ; correlations between variables and pc's
;r=setmask(r,"text","100m"|"200m"|"400m"|"800m"|"1.5km"|"5km"|"10km"|"mara")
setmaskp(r,0,0,0)
setmaskt(r,"100m"|"200m"|"400m"|"800m"|"1.5km"|"5km"|"10km"|"mara",0,0,20)
;
ucircle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
ucircle=setmask(ucircle,"line","thin","dashed")
xline=setmask(#(-1.1,1.1)~#(0,0),"line")
yline=setmask(#(0,0)~#(-1.1,1.1),"line")
;
dic=createdisplay(1,1)
show(dic,1,1,r,ucircle,xline,yline)
setgopt(dic,1,1,"title","Athletic records","xlabel","first PC","ylabel","second PC","border",0)
