; ----------------------------------------------------------------------------
; EBook          sms
; ----------------------------------------------------------------------------
;  See_also      eigsm order setmaskp setmaskl
; ----------------------------------------------------------------------------
;   Macro        SMSpcahealth
; ----------------------------------------------------------------------------
;   Description  SMSpcahealth performs PCA for the US health
;                data and shows the first three principal components in 
;                two-dimensional scatterplots. Additionally, a screeplot
;                of the eigenvalues is displayed.
; ----------------------------------------------------------------------------
library("xplore")
library("plot")
;
x=readm("ushealth")                      ; read data
t=x.text
x=x.double[,3:9]
;x=x/sqrt(var(x))                    ; in case of NPCA
n=rows(x)
{e,v}=eigsm(cov(x))                  ; spectral analysis
tmp=sort(e~v',-1)                    ; sort by eigenvalues
e=tmp[,1]
v=tmp[,2:8]'
;
"eigenvalues and proportions of explained variance"
(e~(e/sum(e))~(cumsum(e)/sum(e)))'
"2 eigenvectors"
v[,1:2]'
;
setsize(500,500)
di=createdisplay(1,1)                
y=x*v                                ; principal components
;
x12=y[,1:2]
setmaskp(x12,0,0,0)
setmaskt(x12,t,0,0,18)
;
show(di,1,1,x12)
setgopt(di,1,1,"title","US health","xlabel","pc1","ylabel","pc2","border",0)
;
r=corr(y~x)
r=r[8:14,1:2]                ; correlations between variables and pc's
r=setmask(r,"text","acc"|"card"|"canc"|"pul"|"pneu"|"diab"|"liv")
;
ucircle=cos((0:360)/180*pi)~sin((0:360)/180*pi)
ucircle=setmask(ucircle,"line","thin","dashed")
xline=setmask(#(-1.1,1.1)~#(0,0),"line")
yline=setmask(#(0,0)~#(-1.1,1.1),"line")
;
setsize(500,250)
dic=createdisplay(1,2)
show(dic,1,1,r,ucircle,xline,yline)
show(dic,1,2,(1:7)~e)                 ; screeplot of eigenvalues
setgopt(dic,1,2, "title","eigenvalues of S","xlabel","index","ylabel","lambda","border",0)
setgopt(dic,1,1,"title","US health","xlabel","first PC","ylabel","second PC","border",0)
