; -----------------------------------------------------------------
; EBook         sms
; -----------------------------------------------------------------
;  See_also     simdep setgopt
; -----------------------------------------------------------------
;   Macro        SMSsimpdbank
; -----------------------------------------------------------------
;   Description  SMSsimpdbank calculated simplicial depth
;                of the bank notes data ("bank2.dat") 
; -----------------------------------------------------------------
library("stats")
library("xplore")
;
; simulate data
;
 x=read("bank2")
 randomize(2006)                 ; sets random seed
 n=20                            ; sample size
; xi=1:10  
 xi=sort(ceil(200*uniform(n)))         ; indices of chosen subsample
; xi=37|32|3|98|67|50|89|171|116|168|148|194|108|135|193|145|165|114|146|173
 xx=index(x, xi)                 ; extracts subsample from x
 xxi=string("%3.0f", xi)         ; labels

;
; PCs
; 
 x=xx-mean(xx)
 {e, v}=eigsm(cov(x))            ; eigensystem analysis
 tmp=sort(e~v',-1)               ; sort by eigenvalues
 e=tmp[,1]
 v=tmp[1:2,2:7]'
 y=x*v                         ; PCA transformation
 {med,dep} = simdep(y)
 "Deepest point"
 med
 tc=(xi<101)
 ng=sum(tc)
 nf=n-ng
 med12 = median(y)
 "coordinatewise median"
 med12
 setmaskp(med12,1,4,15)         ; pointwise median is blue triangle

 "GENUINE"
 {medg,depg} = simdep(y[1:ng])
 "Deepest point"
 medg=medg'
 medg
 setmaskp(medg,4,12,8)          ; deepest point is red star
 medg12 = median(y[1:ng])
 "coordinatewise median"
 medg12
 setmaskp(medg12,1,4,8)         ; pointwise median is smaller blue triangle

 "COUNTERFEIT"
 {medf,depf} = simdep(y[(ng+1):n])
 "Deepest point"
 medf=medf'
 medf
 setmaskp(medf,4,12,8)          ; deepest point is red star
 medf12 = median(y[(ng+1):n])
 "coordinatewise median"
 medf12
 setmaskp(medf12,1,4,8)         ; pointwise median is smaller blue triangle
 

 textdep=string("%.0f",dep)

; labels=string("%.0f", xi)
; setmaskt(y, labels, tc, 0, 14)
; setmaskp(y, 0, 0, 0)
;
; draw a depth graph and median
;
d = createdisplay(1,1)
dat = y
col = round(5*dep/max(dep))
setmaskp(dat, col, 0, 0)
setmaskt(dat, textdep, 1, 0, 18)
median = med';*v
setmaskp(median,4,12,15)    ; median is red big star
show(d, 1, 1, dat, median, med12, medg, medf, medg12, medf12)
setgopt(d, 1, 1, "title", "Simplicial depth of Swiss Bank Notes", "xlabel", "PC1", "ylabel", "PC2","border",0)

