; ----------------------------------------------------------------------------
; EBook          sms
; ----------------------------------------------------------------------------
;  See_also      svm
; ----------------------------------------------------------------------------
;   Macro        SMSsvmspiral
; ----------------------------------------------------------------------------
;   Description  SMSsvmspiral performs SVM on the spiral data set
; ----------------------------------------------------------------------------

library("xplore");
library("plot");
library("xclust");


nm=400/2;
randomize(2);
t=cumsum(matrix(nm,1))/nm;
phi=t*3*pi;
rho=1+3*cumsum(matrix(nm,1))/nm;
x1=rho.*cos(phi)~rho.*sin(phi)~matrix(nm,1);
x2=rho.*cos(phi+pi)~rho.*sin(phi+pi)~(-1)*matrix(nm,1);
AT=x1|x2;
AT[,1:2]=AT[,1:2]+0.1*normal(rows(AT),2);


nsteps=200;
origin=#(-4.5, -4.5);
endpoints=#(4.5, 4.5);
steps=(endpoints-origin)/nsteps;
npoints=#(nsteps+1, nsteps+1);
AC=grid(origin,steps,npoints);

V=svm(AT, AC, 0.4, 1.2);

svmplot(AT,AC,V);

setgopt(svmdi,1,1,"xlabel","X1","ylabel","X2","title","Scores");
z=sort(AC~V,#(1,2,3));

{lt,pt} = contour2(z, 0.0);
setmaskp(pt, 7, 9, 2);
adddata(svmdi, 1, 1, pt);

{lt,pt} = contour2(z, 1.0);
setmaskp(pt, 0, 9, 2);
adddata(svmdi, 1, 1, pt);

{lt,pt} = contour2(z, -1.0);
setmaskp(pt, 0, 9, 2);
adddata(svmdi, 1, 1, pt);

